#############################################################################

# MODEL SETUP START
  
# Process and data definition 	
param nPlants;          			# Number of plants
set P := 1..nPlants;    			# Index set of plants
param nT;					# Number of periods 
set T := 1..nT;	        			# Vector of time indices
param r;					# Interest rate

# Data and variables in the plant value expression (integral solved by the Simpson method) 
param kappa {T, P};				# Speed of mean reversion
param sigma_chi {T, P};				# Volatility of the short term deviations in the spark spread
param sigma_xi {T, P};				# Volatility of the long term spark spread
param rho {T, P};				# Correlation between short term deviations and long term spark spread
param mu {T, P};				# Expected long term drift of the spark spread
param chi0 {T, P};				# Short term deviation in the spark spread at time t=0
param xi0 {T, P};				# Long term spark spread at time t=0
param G {T, P};					# Fixed operating and maintenance costs of the plant
param status {T, P};       			# Status of plant a at time t
param cap {T, P};				# Capacity of the plant 
param beta1 {T, P} >=0; 			# Positive root of the corresponding fundamental quadratic equation
param beta2 {T, P} <=0;				# Negative root of the corresponding fundamental quadratic equation
param eff {T, P};				# Efficiency of the plant
param sbtime {T, P};				# Time in standby
param PI := 3.141592;				# The number PI
param lower;					# Lower bound for the integral 
param upper;					# Upper bound for the integral
param n;					# Number of iterations (even number)				
param h := (upper - lower) / n;			# h-factor used in Simpsons method

# Defining structural parameters and endogenous variables 


# Linear expressions for the structural parameters
# Restart costs: 	(R1+R2*cap[t,a]+R3*sbtime[t,a])
# Maintenance costs: 	(M1+M2*cap[t,a])
# Salvage value: 	(S1+S2*cap[t,a]+S3*eff[t,a])

# Structural parameters and their boundaries
var R1 >=0;					# General restart cost parameter
var R2 >=0;					# Restart cost parameter associated with the capacity of the plant
var R3 >=0;					# Restart cost parameter associated with time spent in standby state for a plant
var M1 >=0;					# General maintenance cost parameter
var M2 >=0;					# Maintenance cost parameter associated with the capacity of the plant
var S1 <=0;					# General abandonment costs 
var S2 >=0;					# Salvage value parameter associated with the capacity of the plant
var S3 >=0;					# Salvage value parameter associated with the efficiency of the plant

# Endogenous variables and their boundaries
var startup {T, P} <= 50;			# Trigger spark spread (long term) for startup. Boundary chosen to reduce processing time.
var shutdown {T, P}; 				# Trigger spark spread (long term) for shutdown
var abandon {T, P} >= -100;			# Trigger spark spread (long term) for abandon. Boundary chosen to reduce processing time.
var D1 {T, P} >=0;				# Option value constant - startup
var D2 {T, P} >=0;				# Option value constant - abandon	
var B2 {T, P} >=0;				# Option value constant - shutdown
										
# Defining initial parameter values
param inistartup;				# Suggested initial value for spark spread trigger for startup
param inishutdown;				# Suggested initial value for spark spread trigger for shutdown
param iniabandon;				# Suggested initial value for spark spread trigger for abandon
						
# Defining auxiliary penalty variables
var delta1 {T, P} >=0;				# Delta 1: Penalty for violating the OP-OP status change 
var delta2 {T, P} >=0;				# Delta 2: Penalty for violating the OP-SB status change 
var delta3 {T, P} >=0;				# Delta 3: Penalty for violating the SB-OP status change 
var delta4 {T, P} >=0;				# Delta 4: Penalty for violating the first SB-SB status change 
var delta5 {T, P} >=0;				# Delta 5: Penalty for violating the second SB-SB status change 
var delta6 {T, P} >=0;				# Delta 6: Penalty for violating the SB-AB status change 

# Defining the parameters of the for-loops used to compute the numerical values of the Simpsons method
param iJ :=floor(n/2);				# First part of the loop
set J := 1..iJ;					# Index for the first part of the loop
param iK :=floor(n/2-1);			# Second part of the loop
set K := 1..iK;					# Index for the second part of the loop
param xj{J};					# First boundary
param xk{K};					# Second boundary

# MODEL SETUP END

#############################################################################








#############################################################################

# SETUP OF THE OPTIMIZATION PROBLEM


# Defining objective function 

minimize realoptions:
sum {t in 2..nT, a in P} (delta1[t,a] + delta2[t,a] + delta3[t,a] + delta4[t,a] + delta5[t,a] + delta6[t,a]);


# To handle all possible penalties we have made one constraint for each possible status change. This can be 
# done more efficient, and for cases with two possible states only one constraint is necessary. Note that we 
# also have added a constraint to prevent the possibility of the plant going straight from operating
# to abandon, see opab. 

# Defining the constraints


# From operating state to operating state

subject to opop {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=2}:
delta1[t,a] >= shutdown[t,a] - xi0[t,a];

subject to opopboundary1 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=2}:
startup[t,a] >= shutdown[t,a];

subject to opopboundary2 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=2}:
shutdown[t,a] >= abandon[t,a];

subject to opopVM1 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=2}:
h/3*((cap[t,a]*(exp(-r*lower) * (sqrt(sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*lower))+sigma_xi[t,a]^2 * lower + 2*(1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))+(cap[t,a]*(exp(-r*upper) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*upper))+sigma_xi[t,a]^2 * upper + 2*(1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))) + sum{j in J} ( (4*h/3)*(cap[t,a]*(exp(-r*xj[j]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xj[j]))+sigma_xi[t,a]^2 * xj[j] + 2*(1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*(exp(-r*xk[k]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xk[k]))+sigma_xi[t,a]^2 * xk[k] + 2*(1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) - G[t,a]/r*(1-exp(-r*upper)) + B2[t,a] * exp(beta2[t,a] * shutdown[t,a]) = D1[t,a] * exp(beta1[t,a] * shutdown[t,a]) + D2[t,a] * exp(beta2[t,a] * shutdown[t,a]) - (M1+M2*cap[t,a])/r;

subject to opopSP1 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=2}:
( h/3*(cap[t,a]*exp(-r*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + ( h/3*(cap[t,a]*exp(-r*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{j in J} ( (4*h/3)*(cap[t,a]*exp(-r*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*exp(-r*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + beta2[t,a] * B2[t,a] *  exp(beta2[t,a] * shutdown[t,a]) = beta1[t,a] * D1[t,a] * exp(beta1[t,a] * shutdown[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * shutdown[t,a]);

subject to opopVM2 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=2}:
D1[t,a] * exp(beta1[t,a] * startup[t,a]) + D2[t,a] * exp(beta2[t,a] * startup[t,a]) - (M1+M2*cap[t,a])/r = (h/3*((cap[t,a]*(exp(-r*lower) * (sqrt(sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*lower))+sigma_xi[t,a]^2 * lower + 2*(1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))+(cap[t,a]*(exp(-r*upper) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*upper))+sigma_xi[t,a]^2 * upper + 2*(1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))) + sum{j in J} ( (4*h/3)*(cap[t,a]*(exp(-r*xj[j]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xj[j]))+sigma_xi[t,a]^2 * xj[j] + 2*(1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*(exp(-r*xk[k]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xk[k]))+sigma_xi[t,a]^2 * xk[k] + 2*(1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) )) - G[t,a]/r*(1-exp(-r*upper)) + B2[t,a] * exp(beta2[t,a] * startup[t,a]) - (R1+R2*cap[t,a]+R3*sbtime[t,a]);

subject to opopSP2 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=2}:
beta1[t,a] * D1[t,a] * exp(beta1[t,a] * startup[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * startup[t,a]) = ( h/3*(cap[t,a]*exp(-r*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + ( h/3*(cap[t,a]*exp(-r*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{j in J} ( (4*h/3)*(cap[t,a]*exp(-r*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*exp(-r*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + beta2[t,a] * B2[t,a] * exp(beta2[t,a] * startup[t,a]);

subject to opopVM3 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=2}:
D1[t,a] * exp(beta1[t,a] * abandon[t,a]) + D2[t,a] * exp(beta2[t,a] * abandon[t,a]) - (M1+M2*cap[t,a])/r = (S1+S2*cap[t,a]+S3*eff[t,a]);

subject to opopSP3 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=2}:
beta1[t,a] * D1[t,a] * exp(beta1[t,a] * abandon[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * abandon[t,a]) = 0;

subject to opopNPV1 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=2}:
shutdown[t,a] <= (G[t,a]-(M1+M2*cap[t,a]))/cap[t,a] - mu[t,a]/r - r*chi0[t,a]/(r+kappa[t,a]);

subject to opopNPV2 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=2}:
startup[t,a] >= ((R1+R2*cap[t,a]+R3*sbtime[t,a])*r + G[t,a] - (M1+M2*cap[t,a]))/cap[t,a] - chi0[t,a]*r/(r+kappa[t,a]) - mu[t,a]/r;

# From operating state to standby state

subject to opsb {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=1}:
delta2[t,a] >= xi0[t,a] - shutdown[t,a];

subject to opsbboundary1 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=1}:
startup[t,a] >= shutdown[t,a];

subject to opsbboundary2 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=1}:
shutdown[t,a] >= abandon[t,a];

subject to opsbVM1 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=1}:
h/3*((cap[t,a]*(exp(-r*lower) * (sqrt(sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*lower))+sigma_xi[t,a]^2 * lower + 2*(1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))+(cap[t,a]*(exp(-r*upper) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*upper))+sigma_xi[t,a]^2 * upper + 2*(1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))) + sum{j in J} ( (4*h/3)*(cap[t,a]*(exp(-r*xj[j]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xj[j]))+sigma_xi[t,a]^2 * xj[j] + 2*(1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*(exp(-r*xk[k]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xk[k]))+sigma_xi[t,a]^2 * xk[k] + 2*(1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) - G[t,a]/r*(1-exp(-r*upper)) + B2[t,a] * exp(beta2[t,a] * shutdown[t,a]) = D1[t,a] * exp(beta1[t,a] * shutdown[t,a]) + D2[t,a] * exp(beta2[t,a] * shutdown[t,a]) - (M1+M2*cap[t,a])/r;

subject to opsbSP1 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=1}:
( h/3*(cap[t,a]*exp(-r*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + ( h/3*(cap[t,a]*exp(-r*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{j in J} ( (4*h/3)*(cap[t,a]*exp(-r*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*exp(-r*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + beta2[t,a] * B2[t,a] *  exp(beta2[t,a] * shutdown[t,a]) = beta1[t,a] * D1[t,a] * exp(beta1[t,a] * shutdown[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * shutdown[t,a]);

subject to opsbVM2 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=1}:
D1[t,a] * exp(beta1[t,a] * startup[t,a]) + D2[t,a] * exp(beta2[t,a] * startup[t,a]) - (M1+M2*cap[t,a])/r = (h/3*((cap[t,a]*(exp(-r*lower) * (sqrt(sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*lower))+sigma_xi[t,a]^2 * lower + 2*(1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))+(cap[t,a]*(exp(-r*upper) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*upper))+sigma_xi[t,a]^2 * upper + 2*(1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))) + sum{j in J} ( (4*h/3)*(cap[t,a]*(exp(-r*xj[j]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xj[j]))+sigma_xi[t,a]^2 * xj[j] + 2*(1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*(exp(-r*xk[k]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xk[k]))+sigma_xi[t,a]^2 * xk[k] + 2*(1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) )) - G[t,a]/r*(1-exp(-r*upper)) + B2[t,a] * exp(beta2[t,a] * startup[t,a]) - (R1+R2*cap[t,a]+R3*sbtime[t,a]);

subject to opsbSP2 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=1}:
beta1[t,a] * D1[t,a] * exp(beta1[t,a] * startup[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * startup[t,a]) = ( h/3*(cap[t,a]*exp(-r*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + ( h/3*(cap[t,a]*exp(-r*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{j in J} ( (4*h/3)*(cap[t,a]*exp(-r*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*exp(-r*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + beta2[t,a] * B2[t,a] * exp(beta2[t,a] * startup[t,a]);

subject to opsbVM3 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=1}:
D1[t,a] * exp(beta1[t,a] * abandon[t,a]) + D2[t,a] * exp(beta2[t,a] * abandon[t,a]) - (M1+M2*cap[t,a])/r = (S1+S2*cap[t,a]+S3*eff[t,a]);

subject to opsbSP3 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=1}:
beta1[t,a] * D1[t,a] * exp(beta1[t,a] * abandon[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * abandon[t,a]) = 0;

subject to opsbNPV1 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=1}:
shutdown[t,a] <= (G[t,a]-(M1+M2*cap[t,a]))/cap[t,a] - mu[t,a]/r - r*chi0[t,a]/(r+kappa[t,a]);

subject to opsbNPV2 {t in 2..nT, a in P: status[t-1,a]=2 && status[t,a]=1}:
startup[t,a] >= ((R1+R2*cap[t,a]+R3*sbtime[t,a])*r + G[t,a] - (M1+M2*cap[t,a]))/cap[t,a] - chi0[t,a]*r/(r+kappa[t,a]) - mu[t,a]/r;

# From standby state to operating state

subject to sbop {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=2}:
delta3[t,a] >= startup[t,a] - xi0[t,a];

subject to sbopboundary1 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=2}:
startup[t,a] >= shutdown[t,a];

subject to sbopboundary2 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=2}:
shutdown[t,a] >= abandon[t,a];

subject to sbopVM1 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=2}:
h/3*((cap[t,a]*(exp(-r*lower) * (sqrt(sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*lower))+sigma_xi[t,a]^2 * lower + 2*(1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))+(cap[t,a]*(exp(-r*upper) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*upper))+sigma_xi[t,a]^2 * upper + 2*(1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))) + sum{j in J} ( (4*h/3)*(cap[t,a]*(exp(-r*xj[j]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xj[j]))+sigma_xi[t,a]^2 * xj[j] + 2*(1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*(exp(-r*xk[k]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xk[k]))+sigma_xi[t,a]^2 * xk[k] + 2*(1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) - G[t,a]/r*(1-exp(-r*upper)) + B2[t,a] * exp(beta2[t,a] * shutdown[t,a]) = D1[t,a] * exp(beta1[t,a] * shutdown[t,a]) + D2[t,a] * exp(beta2[t,a] * shutdown[t,a]) - (M1+M2*cap[t,a])/r;

subject to sbopSP1 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=2}:
( h/3*(cap[t,a]*exp(-r*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + ( h/3*(cap[t,a]*exp(-r*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{j in J} ( (4*h/3)*(cap[t,a]*exp(-r*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*exp(-r*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + beta2[t,a] * B2[t,a] *  exp(beta2[t,a] * shutdown[t,a]) = beta1[t,a] * D1[t,a] * exp(beta1[t,a] * shutdown[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * shutdown[t,a]);

subject to sbopVM2 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=2}:
D1[t,a] * exp(beta1[t,a] * startup[t,a]) + D2[t,a] * exp(beta2[t,a] * startup[t,a]) - (M1+M2*cap[t,a])/r = (h/3*((cap[t,a]*(exp(-r*lower) * (sqrt(sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*lower))+sigma_xi[t,a]^2 * lower + 2*(1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))+(cap[t,a]*(exp(-r*upper) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*upper))+sigma_xi[t,a]^2 * upper + 2*(1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))) + sum{j in J} ( (4*h/3)*(cap[t,a]*(exp(-r*xj[j]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xj[j]))+sigma_xi[t,a]^2 * xj[j] + 2*(1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*(exp(-r*xk[k]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xk[k]))+sigma_xi[t,a]^2 * xk[k] + 2*(1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) )) - G[t,a]/r*(1-exp(-r*upper)) + B2[t,a] * exp(beta2[t,a] * startup[t,a]) - (R1+R2*cap[t,a]+R3*sbtime[t,a]);

subject to sbopSP2 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=2}:
beta1[t,a] * D1[t,a] * exp(beta1[t,a] * startup[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * startup[t,a]) = ( h/3*(cap[t,a]*exp(-r*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + ( h/3*(cap[t,a]*exp(-r*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{j in J} ( (4*h/3)*(cap[t,a]*exp(-r*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*exp(-r*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + beta2[t,a] * B2[t,a] * exp(beta2[t,a] * startup[t,a]);

subject to sbopVM3 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=2}:
D1[t,a] * exp(beta1[t,a] * abandon[t,a]) + D2[t,a] * exp(beta2[t,a] * abandon[t,a]) - (M1+M2*cap[t,a])/r = (S1+S2*cap[t,a]+S3*eff[t,a]);

subject to sbopSP3 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=2}:
beta1[t,a] * D1[t,a] * exp(beta1[t,a] * abandon[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * abandon[t,a]) = 0;

subject to sbopNPV1 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=2}:
shutdown[t,a] <= (G[t,a]-(M1+M2*cap[t,a]))/cap[t,a] - mu[t,a]/r - r*chi0[t,a]/(r+kappa[t,a]);

subject to sbopNPV2 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=2}:
startup[t,a] >= ((R1+R2*cap[t,a]+R3*sbtime[t,a])*r + G[t,a] - (M1+M2*cap[t,a]))/cap[t,a] - chi0[t,a]*r/(r+kappa[t,a]) - mu[t,a]/r;

# From standby state to standby state - upper boundary

subject to sbsb1 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
delta4[t,a] >= xi0[t,a] - startup[t,a];

subject to sbsb1boundary1 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
startup[t,a] >= shutdown[t,a];

subject to sbsb1boundary2 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
shutdown[t,a] >= abandon[t,a];

subject to sbsb1VM1 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
h/3*((cap[t,a]*(exp(-r*lower) * (sqrt(sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*lower))+sigma_xi[t,a]^2 * lower + 2*(1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))+(cap[t,a]*(exp(-r*upper) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*upper))+sigma_xi[t,a]^2 * upper + 2*(1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))) + sum{j in J} ( (4*h/3)*(cap[t,a]*(exp(-r*xj[j]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xj[j]))+sigma_xi[t,a]^2 * xj[j] + 2*(1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*(exp(-r*xk[k]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xk[k]))+sigma_xi[t,a]^2 * xk[k] + 2*(1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) - G[t,a]/r*(1-exp(-r*upper)) + B2[t,a] * exp(beta2[t,a] * shutdown[t,a]) = D1[t,a] * exp(beta1[t,a] * shutdown[t,a]) + D2[t,a] * exp(beta2[t,a] * shutdown[t,a]) - (M1+M2*cap[t,a])/r;

subject to sbsb1SP1 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
( h/3*(cap[t,a]*exp(-r*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + ( h/3*(cap[t,a]*exp(-r*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{j in J} ( (4*h/3)*(cap[t,a]*exp(-r*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*exp(-r*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + beta2[t,a] * B2[t,a] *  exp(beta2[t,a] * shutdown[t,a]) = beta1[t,a] * D1[t,a] * exp(beta1[t,a] * shutdown[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * shutdown[t,a]);

subject to sbsb1VM2 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
D1[t,a] * exp(beta1[t,a] * startup[t,a]) + D2[t,a] * exp(beta2[t,a] * startup[t,a]) - (M1+M2*cap[t,a])/r = (h/3*((cap[t,a]*(exp(-r*lower) * (sqrt(sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*lower))+sigma_xi[t,a]^2 * lower + 2*(1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))+(cap[t,a]*(exp(-r*upper) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*upper))+sigma_xi[t,a]^2 * upper + 2*(1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))) + sum{j in J} ( (4*h/3)*(cap[t,a]*(exp(-r*xj[j]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xj[j]))+sigma_xi[t,a]^2 * xj[j] + 2*(1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*(exp(-r*xk[k]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xk[k]))+sigma_xi[t,a]^2 * xk[k] + 2*(1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) )) - G[t,a]/r*(1-exp(-r*upper)) + B2[t,a] * exp(beta2[t,a] * startup[t,a]) - (R1+R2*cap[t,a]+R3*sbtime[t,a]);

subject to sbsb1SP2 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
beta1[t,a] * D1[t,a] * exp(beta1[t,a] * startup[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * startup[t,a]) = ( h/3*(cap[t,a]*exp(-r*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + ( h/3*(cap[t,a]*exp(-r*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{j in J} ( (4*h/3)*(cap[t,a]*exp(-r*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*exp(-r*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + beta2[t,a] * B2[t,a] * exp(beta2[t,a] * startup[t,a]);

subject to sbsb1VM3 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
D1[t,a] * exp(beta1[t,a] * abandon[t,a]) + D2[t,a] * exp(beta2[t,a] * abandon[t,a]) - (M1+M2*cap[t,a])/r = (S1+S2*cap[t,a]+S3*eff[t,a]);

subject to sbsb1SP3 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
beta1[t,a] * D1[t,a] * exp(beta1[t,a] * abandon[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * abandon[t,a]) = 0;

subject to sbsb1NPV1 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
shutdown[t,a] <= (G[t,a]-(M1+M2*cap[t,a]))/cap[t,a] - mu[t,a]/r - r*chi0[t,a]/(r+kappa[t,a]);

subject to sbsb1NPV2 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
startup[t,a] >= ((R1+R2*cap[t,a]+R3*sbtime[t,a])*r + G[t,a] - (M1+M2*cap[t,a]))/cap[t,a] - chi0[t,a]*r/(r+kappa[t,a]) - mu[t,a]/r;

# From standby state to standby state - lower boundary

subject to sbsb2 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
delta5[t,a] >= abandon[t,a] - xi0[t,a];

subject to sbsb2boundary1 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
startup[t,a] >= shutdown[t,a];

subject to sbsb2boundary2 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
shutdown[t,a] >= abandon[t,a];

subject to sbsb2VM1 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
h/3*((cap[t,a]*(exp(-r*lower) * (sqrt(sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*lower))+sigma_xi[t,a]^2 * lower + 2*(1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))+(cap[t,a]*(exp(-r*upper) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*upper))+sigma_xi[t,a]^2 * upper + 2*(1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))) + sum{j in J} ( (4*h/3)*(cap[t,a]*(exp(-r*xj[j]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xj[j]))+sigma_xi[t,a]^2 * xj[j] + 2*(1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*(exp(-r*xk[k]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xk[k]))+sigma_xi[t,a]^2 * xk[k] + 2*(1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) - G[t,a]/r*(1-exp(-r*upper)) + B2[t,a] * exp(beta2[t,a] * shutdown[t,a]) = D1[t,a] * exp(beta1[t,a] * shutdown[t,a]) + D2[t,a] * exp(beta2[t,a] * shutdown[t,a]) - (M1+M2*cap[t,a])/r;

subject to sbsb2SP1 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
( h/3*(cap[t,a]*exp(-r*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + ( h/3*(cap[t,a]*exp(-r*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{j in J} ( (4*h/3)*(cap[t,a]*exp(-r*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*exp(-r*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + beta2[t,a] * B2[t,a] *  exp(beta2[t,a] * shutdown[t,a]) = beta1[t,a] * D1[t,a] * exp(beta1[t,a] * shutdown[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * shutdown[t,a]);

subject to sbsb2VM2 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
D1[t,a] * exp(beta1[t,a] * startup[t,a]) + D2[t,a] * exp(beta2[t,a] * startup[t,a]) - (M1+M2*cap[t,a])/r = (h/3*((cap[t,a]*(exp(-r*lower) * (sqrt(sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*lower))+sigma_xi[t,a]^2 * lower + 2*(1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))+(cap[t,a]*(exp(-r*upper) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*upper))+sigma_xi[t,a]^2 * upper + 2*(1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))) + sum{j in J} ( (4*h/3)*(cap[t,a]*(exp(-r*xj[j]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xj[j]))+sigma_xi[t,a]^2 * xj[j] + 2*(1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*(exp(-r*xk[k]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xk[k]))+sigma_xi[t,a]^2 * xk[k] + 2*(1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) )) - G[t,a]/r*(1-exp(-r*upper)) + B2[t,a] * exp(beta2[t,a] * startup[t,a]) - (R1+R2*cap[t,a]+R3*sbtime[t,a]);

subject to sbsb2SP2 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
beta1[t,a] * D1[t,a] * exp(beta1[t,a] * startup[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * startup[t,a]) = ( h/3*(cap[t,a]*exp(-r*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + ( h/3*(cap[t,a]*exp(-r*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{j in J} ( (4*h/3)*(cap[t,a]*exp(-r*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*exp(-r*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + beta2[t,a] * B2[t,a] * exp(beta2[t,a] * startup[t,a]);

subject to sbsb2VM3 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
D1[t,a] * exp(beta1[t,a] * abandon[t,a]) + D2[t,a] * exp(beta2[t,a] * abandon[t,a]) - (M1+M2*cap[t,a])/r = (S1+S2*cap[t,a]+S3*eff[t,a]);

subject to sbsb2SP3 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
beta1[t,a] * D1[t,a] * exp(beta1[t,a] * abandon[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * abandon[t,a]) = 0;

subject to sbsb2NPV1 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
shutdown[t,a] <= (G[t,a]-(M1+M2*cap[t,a]))/cap[t,a] - mu[t,a]/r - r*chi0[t,a]/(r+kappa[t,a]);

subject to sbsb2NPV2 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=1}:
startup[t,a] >= ((R1+R2*cap[t,a]+R3*sbtime[t,a])*r + G[t,a] - (M1+M2*cap[t,a]))/cap[t,a] - chi0[t,a]*r/(r+kappa[t,a]) - mu[t,a]/r;

# From standby state to abandon state 

subject to sbab {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=0}:
delta6[t,a] >= xi0[t,a] - abandon[t,a];

subject to sbabboundary1 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=0}:
startup[t,a] >= shutdown[t,a];

subject to sbabboundary2 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=0}:
shutdown[t,a] >= abandon[t,a];

subject to sbabVM1 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=0}:
h/3*((cap[t,a]*(exp(-r*lower) * (sqrt(sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*lower))+sigma_xi[t,a]^2 * lower + 2*(1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))+(cap[t,a]*(exp(-r*upper) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*upper))+sigma_xi[t,a]^2 * upper + 2*(1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))) + sum{j in J} ( (4*h/3)*(cap[t,a]*(exp(-r*xj[j]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xj[j]))+sigma_xi[t,a]^2 * xj[j] + 2*(1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*(exp(-r*xk[k]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xk[k]))+sigma_xi[t,a]^2 * xk[k] + 2*(1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) - G[t,a]/r*(1-exp(-r*upper)) + B2[t,a] * exp(beta2[t,a] * shutdown[t,a]) = D1[t,a] * exp(beta1[t,a] * shutdown[t,a]) + D2[t,a] * exp(beta2[t,a] * shutdown[t,a]) - (M1+M2*cap[t,a])/r;

subject to sbabSP1 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=0}:
( h/3*(cap[t,a]*exp(-r*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + shutdown[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + ( h/3*(cap[t,a]*exp(-r*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + shutdown[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{j in J} ( (4*h/3)*(cap[t,a]*exp(-r*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*exp(-r*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + shutdown[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + beta2[t,a] * B2[t,a] *  exp(beta2[t,a] * shutdown[t,a]) = beta1[t,a] * D1[t,a] * exp(beta1[t,a] * shutdown[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * shutdown[t,a]);

subject to sbabVM2 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=0}:
D1[t,a] * exp(beta1[t,a] * startup[t,a]) + D2[t,a] * exp(beta2[t,a] * startup[t,a]) - (M1+M2*cap[t,a])/r = (h/3*((cap[t,a]*(exp(-r*lower) * (sqrt(sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*lower))+sigma_xi[t,a]^2 * lower + 2*(1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))+(cap[t,a]*(exp(-r*upper) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)^2 / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*upper))+sigma_xi[t,a]^2 * upper + 2*(1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) )))) + sum{j in J} ( (4*h/3)*(cap[t,a]*(exp(-r*xj[j]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xj[j]))+sigma_xi[t,a]^2 * xj[j] + 2*(1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*(exp(-r*xk[k]) * (sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]) / sqrt(2*PI) * exp(-((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])^2) / (2* ( sigma_chi[t,a]^2 / (2*kappa[t,a])*(1-exp(-2*kappa[t,a]*xk[k]))+sigma_xi[t,a]^2 * xk[k] + 2*(1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a] / kappa[t,a]))) + (exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))))  ))) )) - G[t,a]/r*(1-exp(-r*upper)) + B2[t,a] * exp(beta2[t,a] * startup[t,a]) - (R1+R2*cap[t,a]+R3*sbtime[t,a]);

subject to sbabSP2 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=0}:
beta1[t,a] * D1[t,a] * exp(beta1[t,a] * startup[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * startup[t,a]) = ( h/3*(cap[t,a]*exp(-r*lower) * (exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*lower) * chi0[t,a] + startup[t,a] + mu[t,a]*lower)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*lower)) + sigma_xi[t,a]^2 * lower + 2 * (1-exp(-kappa[t,a]*lower)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + ( h/3*(cap[t,a]*exp(-r*upper) * (exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*upper) * chi0[t,a] + startup[t,a] + mu[t,a]*upper)/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*upper)) + sigma_xi[t,a]^2 * upper + 2 * (1-exp(-kappa[t,a]*upper)) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{j in J} ( (4*h/3)*(cap[t,a]*exp(-r*xj[j]) * (exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xj[j]) * chi0[t,a] + startup[t,a] + mu[t,a]*xj[j])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xj[j])) + sigma_xi[t,a]^2 * xj[j] + 2 * (1-exp(-kappa[t,a]*xj[j])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + sum{k in K} ( (2*h/3)*(cap[t,a]*exp(-r*xk[k]) * (exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2))/(1+exp(2*0.7988*(exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/(sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))*(1+0.04417*((exp(-kappa[t,a]*xk[k]) * chi0[t,a] + startup[t,a] + mu[t,a]*xk[k])/sqrt (sigma_chi[t,a]^2 / (2*kappa[t,a]) * (1-exp(-2*kappa[t,a]*xk[k])) + sigma_xi[t,a]^2 * xk[k] + 2 * (1-exp(-kappa[t,a]*xk[k])) * rho[t,a] * sigma_chi[t,a] * sigma_xi[t,a]/kappa[t,a]))^2)))) ) ) + beta2[t,a] * B2[t,a] * exp(beta2[t,a] * startup[t,a]);

subject to sbabVM3 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=0}:
D1[t,a] * exp(beta1[t,a] * abandon[t,a]) + D2[t,a] * exp(beta2[t,a] * abandon[t,a]) - (M1+M2*cap[t,a])/r = (S1+S2*cap[t,a]+S3*eff[t,a]);

subject to sbabSP3 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=0}:
beta1[t,a] * D1[t,a] * exp(beta1[t,a] * abandon[t,a]) + beta2[t,a] * D2[t,a] * exp(beta2[t,a] * abandon[t,a]) = 0;

subject to sbabNPV1 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=0}:
shutdown[t,a] <= (G[t,a]-(M1+M2*cap[t,a]))/cap[t,a] - mu[t,a]/r - r*chi0[t,a]/(r+kappa[t,a]);

subject to sbabNPV2 {t in 2..nT, a in P: status[t-1,a]=1 && status[t,a]=0}:
startup[t,a] >= ((R1+R2*cap[t,a]+R3*sbtime[t,a])*r + G[t,a] - (M1+M2*cap[t,a]))/cap[t,a] - chi0[t,a]*r/(r+kappa[t,a]) - mu[t,a]/r;

# Constraint preventing a plant from going straight from operating to abandon

subject to opab {t in 2..nT, a in P: status[t,a]=2}:
D1[t,a] * exp(beta1[t,a] * xi0[t,a]) + D2[t,a] * exp(beta2[t,a] * xi0[t,a]) - (M1+M2*cap[t,a])/r >= (S1+S2*cap[t,a]+S3*eff[t,a]);

# Implicit penalties for generators experiencing abandonment within the data sample

subject to ab1{t in 2..nT, a in P: status[t-1,a]=0}:
(delta1[t,a]=0);

subject to ab2{t in 2..nT, a in P: status[t-1,a]=0}:
(delta2[t,a]=0);

subject to ab3{t in 2..nT, a in P: status[t-1,a]=0}:
(delta3[t,a]=0);

subject to oab1{t in 2..nT, a in P: status[t-1,a]=0}:
(delta4[t,a]=0);

subject to oab2{t in 2..nT, a in P: status[t-1,a]=0}:
(delta5[t,a]=0);

subject to oab3{t in 2..nT, a in P: status[t-1,a]=0}:
(delta6[t,a]=0);

# SETUP OF THE OPTIMIZATION PROBLEM END

#############################################################################







#############################################################################

# ONE DIMENSIONAL PARAMETERS (FOR TESTING OF THE VALUEFUNCTION)

# param beta1;					# Positive root of the corresponding fundamental quadratic equation
# param beta2;					# Negative root of the corresponding fundamental quadratic equation
# param cap :=3.27;				# Capacity of the plant
# param chi0 :=52.90;				# Short term deviation in the spark spread at time t=0
# param xi0 :=62.30;				# Long term spark spread at time t=0
# param mu :=2.18;				# Expected long term drift of the spark spread
# param kappa :=2.60;				# Speed of mean reversion
# param rho :=-0.21;				# Correlation between short term deviations and long term spark spread
# param sigma_chi :=382.2;			# Volatility of the short term deviations in the spark spread
# param sigma_xi :=47.8;			# Volatility of the long term spark spread
# param PI := 3.141592;				# The number of PI
# param G :=50.00;				# Fixed operating and maintenance costs of the plant

# ONE DIMENSIONAL PARAMETERS (FOR TESTING OF THE VALUEFUNCTION) END

#############################################################################







#############################################################################

# ONE DIMENSIONAL FUNCTIONS (FOR TESTING) 

# Approximation of the value function
# param I1 := h/3*((cap*(exp(-r*lower) * (sqrt(sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*lower)) + sigma_xi^2 * lower + 2 * (1-exp(-kappa*lower)) * rho * sigma_chi * sigma_xi/kappa) / sqrt(2*PI) * exp(-(exp(-kappa*lower) * chi0 + xi0 + mu*lower)^2 / (2* ( sigma_chi^2 / (2*kappa)*(1-exp(-2*kappa*lower))+sigma_xi^2 * lower + 2*(1-exp(-kappa*lower)) * rho * sigma_chi * sigma_xi / kappa))) + (exp(-kappa*lower) * chi0 + xi0 + mu*lower) * (exp(2*0.7988*(exp(-kappa*lower) * chi0 + xi0 + mu*lower)/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*lower)) + sigma_xi^2 * lower + 2 * (1-exp(-kappa*lower)) * rho * sigma_chi * sigma_xi/kappa))*(1+0.04417*(exp(-kappa*lower) * chi0 + xi0 + mu*lower)/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*lower)) + sigma_xi^2 * lower + 2 * (1-exp(-kappa*lower)) * rho * sigma_chi * sigma_xi/kappa))^2))/(1+exp(2*0.7988*(exp(-kappa*lower) * chi0 + xi0 + mu*lower)/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*lower)) + sigma_xi^2 * lower + 2 * (1-exp(-kappa*lower)) * rho * sigma_chi * sigma_xi/kappa))*(1+0.04417*(exp(-kappa*lower) * chi0 + xi0 + mu*lower)/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*lower)) + sigma_xi^2 * lower + 2 * (1-exp(-kappa*lower)) * rho * sigma_chi * sigma_xi/kappa))^2)))) )))+(cap*(exp(-r*upper) * (sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*upper)) + sigma_xi^2 * upper + 2 * (1-exp(-kappa*upper)) * rho * sigma_chi * sigma_xi/kappa) / sqrt(2*PI) * exp(-(exp(-kappa*upper) * chi0 + xi0 + mu*upper)^2 / (2* ( sigma_chi^2 / (2*kappa)*(1-exp(-2*kappa*upper))+sigma_xi^2 * upper + 2*(1-exp(-kappa*upper)) * rho * sigma_chi * sigma_xi / kappa))) + (exp(-kappa*upper) * chi0 + xi0 + mu*upper) * (exp(2*0.7988*(exp(-kappa*upper) * chi0 + xi0 + mu*upper)/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*upper)) + sigma_xi^2 * upper + 2 * (1-exp(-kappa*upper)) * rho * sigma_chi * sigma_xi/kappa))*(1+0.04417*(exp(-kappa*upper) * chi0 + xi0 + mu*upper)/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*upper)) + sigma_xi^2 * upper + 2 * (1-exp(-kappa*upper)) * rho * sigma_chi * sigma_xi/kappa))^2))/(1+exp(2*0.7988*(exp(-kappa*upper) * chi0 + xi0 + mu*upper)/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*upper)) + sigma_xi^2 * upper + 2 * (1-exp(-kappa*upper)) * rho * sigma_chi * sigma_xi/kappa))*(1+0.04417*(exp(-kappa*upper) * chi0 + xi0 + mu*upper)/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*upper)) + sigma_xi^2 * upper + 2 * (1-exp(-kappa*upper)) * rho * sigma_chi * sigma_xi/kappa))^2)))) ))));
# param I2 := sum{j in J} ( (4*h/3)*(cap*(exp(-r*xj[j]) * (sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xj[j])) + sigma_xi^2 * xj[j] + 2 * (1-exp(-kappa*xj[j])) * rho * sigma_chi * sigma_xi/kappa) / sqrt(2*PI) * exp(-((exp(-kappa*xj[j]) * chi0 + xi0 + mu*xj[j])^2) / (2* ( sigma_chi^2 / (2*kappa)*(1-exp(-2*kappa*xj[j]))+sigma_xi^2 * xj[j] + 2*(1-exp(-kappa*xj[j])) * rho * sigma_chi * sigma_xi / kappa))) + (exp(-kappa*xj[j]) * chi0 + xi0 + mu*xj[j]) * (exp(2*0.7988*(exp(-kappa*xj[j]) * chi0 + xi0 + mu*xj[j])/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xj[j])) + sigma_xi^2 * xj[j] + 2 * (1-exp(-kappa*xj[j])) * rho * sigma_chi * sigma_xi/kappa))*(1+0.04417*(exp(-kappa*xj[j]) * chi0 + xi0 + mu*xj[j])/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xj[j])) + sigma_xi^2 * xj[j] + 2 * (1-exp(-kappa*xj[j])) * rho * sigma_chi * sigma_xi/kappa))^2))/(1+exp(2*0.7988*(exp(-kappa*xj[j]) * chi0 + xi0 + mu*xj[j])/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xj[j])) + sigma_xi^2 * xj[j] + 2 * (1-exp(-kappa*xj[j])) * rho * sigma_chi * sigma_xi/kappa))*(1+0.04417*(exp(-kappa*xj[j]) * chi0 + xi0 + mu*xj[j])/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xj[j])) + sigma_xi^2 * xj[j] + 2 * (1-exp(-kappa*xj[j])) * rho * sigma_chi * sigma_xi/kappa))^2)))) ))) );
# param I3 := sum{k in K} ( (2*h/3)*(cap*(exp(-r*xk[k]) * (sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xk[k])) + sigma_xi^2 * xk[k] + 2 * (1-exp(-kappa*xk[k])) * rho * sigma_chi * sigma_xi/kappa) / sqrt(2*PI) * exp(-((exp(-kappa*xk[k]) * chi0 + xi0 + mu*xk[k])^2) / (2* ( sigma_chi^2 / (2*kappa)*(1-exp(-2*kappa*xk[k]))+sigma_xi^2 * xk[k] + 2*(1-exp(-kappa*xk[k])) * rho * sigma_chi * sigma_xi / kappa))) + (exp(-kappa*xk[k]) * chi0 + xi0 + mu*xk[k]) * (exp(2*0.7988*(exp(-kappa*xk[k]) * chi0 + xi0 + mu*xk[k])/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xk[k])) + sigma_xi^2 * xk[k] + 2 * (1-exp(-kappa*xk[k])) * rho * sigma_chi * sigma_xi/kappa))*(1+0.04417*(exp(-kappa*xk[k]) * chi0 + xi0 + mu*xk[k])/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xk[k])) + sigma_xi^2 * xk[k] + 2 * (1-exp(-kappa*xk[k])) * rho * sigma_chi * sigma_xi/kappa))^2))/(1+exp(2*0.7988*(exp(-kappa*xk[k]) * chi0 + xi0 + mu*xk[k])/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xk[k])) + sigma_xi^2 * xk[k] + 2 * (1-exp(-kappa*xk[k])) * rho * sigma_chi * sigma_xi/kappa))*(1+0.04417*(exp(-kappa*xk[k]) * chi0 + xi0 + mu*xk[k])/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xk[k])) + sigma_xi^2 * xk[k] + 2 * (1-exp(-kappa*xk[k])) * rho * sigma_chi * sigma_xi/kappa))^2)))) ))) );
# param value :=  I1 + I2 + I3 - G/r*(1-exp(-r*upper)); 		

# Approximation of the derivative of the value function
# param Id1lower := ( h/3*(cap*exp(-r*lower) * (exp(2*0.7988*(exp(-kappa*lower) * chi0 + xi0 + mu*lower)/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*lower)) + sigma_xi^2 * lower + 2 * (1-exp(-kappa*lower)) * rho * sigma_chi * sigma_xi/kappa))*(1+0.04417*(exp(-kappa*lower) * chi0 + xi0 + mu*lower)/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*lower)) + sigma_xi^2 * lower + 2 * (1-exp(-kappa*lower)) * rho * sigma_chi * sigma_xi/kappa))^2))/(1+exp(2*0.7988*(exp(-kappa*lower) * chi0 + xi0 + mu*lower)/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*lower)) + sigma_xi^2 * lower + 2 * (1-exp(-kappa*lower)) * rho * sigma_chi * sigma_xi/kappa))*(1+0.04417*(exp(-kappa*lower) * chi0 + xi0 + mu*lower)/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*lower)) + sigma_xi^2 * lower + 2 * (1-exp(-kappa*lower)) * rho * sigma_chi * sigma_xi/kappa))^2)))) ) );
# param Id1upper := ( h/3*(cap*exp(-r*upper) * (exp(2*0.7988*(exp(-kappa*upper) * chi0 + xi0 + mu*upper)/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*upper)) + sigma_xi^2 * upper + 2 * (1-exp(-kappa*upper)) * rho * sigma_chi * sigma_xi/kappa))*(1+0.04417*(exp(-kappa*upper) * chi0 + xi0 + mu*upper)/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*upper)) + sigma_xi^2 * upper + 2 * (1-exp(-kappa*upper)) * rho * sigma_chi * sigma_xi/kappa))^2))/(1+exp(2*0.7988*(exp(-kappa*upper) * chi0 + xi0 + mu*upper)/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*upper)) + sigma_xi^2 * upper + 2 * (1-exp(-kappa*upper)) * rho * sigma_chi * sigma_xi/kappa))*(1+0.04417*(exp(-kappa*upper) * chi0 + xi0 + mu*upper)/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*upper)) + sigma_xi^2 * upper + 2 * (1-exp(-kappa*upper)) * rho * sigma_chi * sigma_xi/kappa))^2)))) ) );
# param Id2 := sum{j in J} ( (4*h/3)*(cap*exp(-r*xj[j]) * (exp(2*0.7988*(exp(-kappa*xj[j]) * chi0 + xi0 + mu*xj[j])/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xj[j])) + sigma_xi^2 * xj[j] + 2 * (1-exp(-kappa*xj[j])) * rho * sigma_chi * sigma_xi/kappa))*(1+0.04417*(exp(-kappa*xj[j]) * chi0 + xi0 + mu*xj[j])/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xj[j])) + sigma_xi^2 * xj[j] + 2 * (1-exp(-kappa*xj[j])) * rho * sigma_chi * sigma_xi/kappa))^2))/(1+exp(2*0.7988*(exp(-kappa*xj[j]) * chi0 + xi0 + mu*xj[j])/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xj[j])) + sigma_xi^2 * xj[j] + 2 * (1-exp(-kappa*xj[j])) * rho * sigma_chi * sigma_xi/kappa))*(1+0.04417*(exp(-kappa*xj[j]) * chi0 + xi0 + mu*xj[j])/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xj[j])) + sigma_xi^2 * xj[j] + 2 * (1-exp(-kappa*xj[j])) * rho * sigma_chi * sigma_xi/kappa))^2)))) ) );
# param Id3 := sum{k in K} ( (2*h/3)*(cap*exp(-r*xk[k]) * (exp(2*0.7988*(exp(-kappa*xk[k]) * chi0 + xi0 + mu*xk[k])/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xk[k])) + sigma_xi^2 * xk[k] + 2 * (1-exp(-kappa*xk[k])) * rho * sigma_chi * sigma_xi/kappa))*(1+0.04417*(exp(-kappa*xk[k]) * chi0 + xi0 + mu*xk[k])/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xk[k])) + sigma_xi^2 * xk[k] + 2 * (1-exp(-kappa*xk[k])) * rho * sigma_chi * sigma_xi/kappa))^2))/(1+exp(2*0.7988*(exp(-kappa*xk[k]) * chi0 + xi0 + mu*xk[k])/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xk[k])) + sigma_xi^2 * xk[k] + 2 * (1-exp(-kappa*xk[k])) * rho * sigma_chi * sigma_xi/kappa))*(1+0.04417*(exp(-kappa*xk[k]) * chi0 + xi0 + mu*xk[k])/(sqrt (sigma_chi^2 / (2*kappa) * (1-exp(-2*kappa*xk[k])) + sigma_xi^2 * xk[k] + 2 * (1-exp(-kappa*xk[k])) * rho * sigma_chi * sigma_xi/kappa))^2)))) ) );
# param valueder := Id1lower + Id1upper + Id2 + Id3; 	

# ONE DIMENSIONAL FUNCTIONS (FOR TESTING) END

#############################################################################








#############################################################################

# DEFINING THE MLE OPTIMIZATION PROBLEM FOR AMPL 

# Name of the problem
problem realopt:

# Name of the objective function
realoptions,

# List of the variables
shutdown, startup, abandon, delta1, delta2, delta3, delta4, delta5, delta6, R1, R2, R3, S1, S2, S3, M1, M2, D1, D2, B2,

# List of the constraints
opab, oab1, oab2, oab3, ab1, ab2, ab3,  opopNPV1, opopNPV2, opsbNPV1, opsbNPV2, sbopNPV1, sbopNPV2, sbsb1NPV1, sbsb1NPV2, sbsb2NPV1, sbsb2NPV2, sbabNPV1, sbabNPV2, opop, opsb, sbop, sbsb1, sbsb2, sbab, opopboundary1, opopboundary2, opopVM1, opopVM2, opopVM3, opopSP1, opopSP2, opopSP3,  opsbboundary1, opsbboundary2, opsbVM1, opsbVM2, opsbVM3, opsbSP1, opsbSP2, opsbSP3, sbopboundary1, sbopboundary2, sbopVM1, sbopVM2, sbopVM3, sbopSP1, sbopSP2, sbopSP3, sbsb1boundary1, sbsb1boundary2, sbsb1VM1, sbsb1VM2, sbsb1VM3, sbsb1SP1, sbsb1SP2, sbsb1SP3, sbsb2boundary1, sbsb2boundary2, sbsb2VM1, sbsb2VM2, sbsb2VM3, sbsb2SP1, sbsb2SP2, sbsb2SP3, sbabboundary1, sbabboundary2, sbabVM1, sbabVM2, sbabVM3, sbabSP1, sbabSP2, sbabSP3; #, out1, out1boundary1, out1boundary2, out1VM1, out1VM2, out1VM3, out1SP1, out1SP2, out1SP3, out1NPV1, out1NPV2, out2, out2boundary1, out2boundary2, out2VM1, out2VM2, out2VM3, out2SP1, out2SP2, out2SP3, out2NPV1, out2NPV2, notop1, notop2, notop3, onotop1, onotop2, onotop3


# DEFINING THE MLE OPTIMIZATION PROBLEM FOR AMPL END

#############################################################################


  